# UI/UX Feedback

**ID:** Feedback-20260210-170511
**URL:** http://127.0.0.1:6060/
**Date:** 2026-02-10 17:06:06

## Selected Elements



## Feedback

when requesting 6060, it's showing the content from 127.0.0.1:5858, which is not expected, it should show content from 60606

## Screenshot

![Screenshot](./page-screenshot.png)
